==> haskell-lsp0-test-0.11.0.7-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp0-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lsp-test
version:              0.11.0.7
visibility:           public
id:                   lsp-test-0.11.0.7-2zTucuJLXf258xhPVBd4sy
key:                  lsp-test-0.11.0.7-2zTucuJLXf258xhPVBd4sy
license:              BSD-3-Clause
copyright:            2020 Luke Lau
maintainer:           luke_lau@icloud.com
author:               Luke Lau
homepage:             https://github.com/bubba/lsp-test#readme
synopsis:             Functional test framework for LSP servers.
description:
    A test framework for writing tests against
    <https://microsoft.github.io/language-server-protocol/ Language Server Protocol servers>.
    @Language.Haskell.LSP.Test@ launches your server as a subprocess and allows you to simulate a session
    down to the wire, and @Language.Haskell.LSP.Test@ can replay captured sessions from
    <haskell-lsp https://hackage.haskell.org/package/haskell-lsp>.
    To see examples of it in action, check out <https://github.com/haskell/haskell-ide-engine haskell-ide-engine>,
    <https://github.com/haskell/haskell-language-server haskell-language-server> and
    <https://github.com/digital-asset/ghcide ghcide>.

category:             Testing
abi:                  a101f62ad0a522094f62f3853bbb08b1
exposed:              True
exposed-modules:
    Control.Applicative.Combinators from parser-combinators-1.3.0-5jHqYWwdpCqFWQLuYLRvi6:Control.Applicative.Combinators,
    Language.Haskell.LSP.Test, Language.Haskell.LSP.Test.Replay,
    Language.Haskell.LSP.Types from haskell-lsp-types-0.24.0.0-LkxeuMceuQxGTy8ufxPNpE:Language.Haskell.LSP.Types,
    Language.Haskell.LSP.Types.Capabilities from haskell-lsp-types-0.24.0.0-LkxeuMceuQxGTy8ufxPNpE:Language.Haskell.LSP.Types.Capabilities

hidden-modules:
    Language.Haskell.LSP.Test.Compat Language.Haskell.LSP.Test.Decoding
    Language.Haskell.LSP.Test.Exceptions
    Language.Haskell.LSP.Test.Files Language.Haskell.LSP.Test.Messages
    Language.Haskell.LSP.Test.Parsing Language.Haskell.LSP.Test.Server
    Language.Haskell.LSP.Test.Session

import-dirs:          /usr/lib/ghc-9.0.1/site-local/lsp-test-0.11.0.7
library-dirs:         /usr/lib/ghc-9.0.1/site-local/lsp-test-0.11.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/lsp-test-0.11.0.7
hs-libraries:         HSlsp-test-0.11.0.7-2zTucuJLXf258xhPVBd4sy
depends:
    Diff-0.4.0-F7vyJzYzam9CwrUJdg8bD2 Glob-0.10.1-dRrZVZhZlNBlliV80pX2x
    aeson-1.5.6.0-BNspgXAzKp6CkIs2quQxij
    aeson-pretty-0.8.8-1peS9EsGwHFKePlezcWPpY
    ansi-terminal-0.11-GzCyMGIeYlsKFtLmEW08CD
    async-2.2.3-CPBwqhOcknLBTZGzgxEVzJ base-4.15.0.0
    bytestring-0.10.12.1 conduit-1.3.4.1-BLONhohY05o3DaB794imz5
    conduit-parse-0.2.1.0-31uGKF2jvGr5j0CpioE3Oc containers-0.6.4.1
    data-default-0.7.1.1-IvZDod4GR1F6QW3rWcNSTn directory-1.3.6.1
    filepath-1.4.2.1 haskell-lsp-0.24.0.0-CrDt3ZyQwMPGOQL9Z4db5L
    lens-5.0.1-7sIVDM65vzN73vCnPCqKgV mtl-2.2.2
    parser-combinators-1.3.0-5jHqYWwdpCqFWQLuYLRvi6 process-1.6.11.0
    text-1.2.4.1 transformers-0.5.6.2 unix-2.7.2.2
    unordered-containers-0.2.14.0-F4OqjO0JqkT1fpEQ2fUdqU

haddock-interfaces:   /usr/share/doc/haskell-lsp0-test/html/lsp-test.haddock
haddock-html:         /usr/share/doc/haskell-lsp0-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lsp0-test-0.11.0.7-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp0-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lsp-test
version:              0.11.0.7
visibility:           public
id:                   lsp-test-0.11.0.7-2rk6EEnoxSLEzsw8ihkIDu
key:                  lsp-test-0.11.0.7-2rk6EEnoxSLEzsw8ihkIDu
license:              BSD-3-Clause
copyright:            2020 Luke Lau
maintainer:           luke_lau@icloud.com
author:               Luke Lau
homepage:             https://github.com/bubba/lsp-test#readme
synopsis:             Functional test framework for LSP servers.
description:
    A test framework for writing tests against
    <https://microsoft.github.io/language-server-protocol/ Language Server Protocol servers>.
    @Language.Haskell.LSP.Test@ launches your server as a subprocess and allows you to simulate a session
    down to the wire, and @Language.Haskell.LSP.Test@ can replay captured sessions from
    <haskell-lsp https://hackage.haskell.org/package/haskell-lsp>.
    To see examples of it in action, check out <https://github.com/haskell/haskell-ide-engine haskell-ide-engine>,
    <https://github.com/haskell/haskell-language-server haskell-language-server> and
    <https://github.com/digital-asset/ghcide ghcide>.

category:             Testing
abi:                  4c49318edddade52cfac3d62a3a65088
exposed:              True
exposed-modules:
    Control.Applicative.Combinators from parser-combinators-1.3.0-5jHqYWwdpCqFWQLuYLRvi6:Control.Applicative.Combinators,
    Language.Haskell.LSP.Test, Language.Haskell.LSP.Test.Replay,
    Language.Haskell.LSP.Types from haskell-lsp-types-0.24.0.0-Bpkw7G2eRoWAvvhQfyxPcw:Language.Haskell.LSP.Types,
    Language.Haskell.LSP.Types.Capabilities from haskell-lsp-types-0.24.0.0-Bpkw7G2eRoWAvvhQfyxPcw:Language.Haskell.LSP.Types.Capabilities

hidden-modules:
    Language.Haskell.LSP.Test.Compat Language.Haskell.LSP.Test.Decoding
    Language.Haskell.LSP.Test.Exceptions
    Language.Haskell.LSP.Test.Files Language.Haskell.LSP.Test.Messages
    Language.Haskell.LSP.Test.Parsing Language.Haskell.LSP.Test.Server
    Language.Haskell.LSP.Test.Session

import-dirs:          /usr/lib/ghc-9.0.1/site-local/lsp-test-0.11.0.7
library-dirs:         /usr/lib/ghc-9.0.1/site-local/lsp-test-0.11.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/lsp-test-0.11.0.7
hs-libraries:         HSlsp-test-0.11.0.7-2rk6EEnoxSLEzsw8ihkIDu
depends:
    Diff-0.4.0-F7vyJzYzam9CwrUJdg8bD2
    Glob-0.10.1-AcT4P5j2YeME62AGuyYpWq
    aeson-1.5.6.0-9o8y4QVT0ed6zIp89KPO7i
    aeson-pretty-0.8.8-3euViZsPWYWGeeGD66ZoHc
    ansi-terminal-0.11-3dYssvxHKaG2lTcCQ7MiaX
    async-2.2.3-IhTi4VeJesa5W1nGjaCoJA base-4.15.0.0
    bytestring-0.10.12.1 conduit-1.3.4.1-K5eDu05qjl0KVIYFvTpDgh
    conduit-parse-0.2.1.0-48mIFI4tgfCKhutBJUbYw9 containers-0.6.4.1
    data-default-0.7.1.1-IvZDod4GR1F6QW3rWcNSTn directory-1.3.6.1
    filepath-1.4.2.1 haskell-lsp-0.24.0.0-ELvn4cfBsSQ4zFHNAz6jpn
    lens-5.0.1-8BjofPyhl39GhYn8lDfGmL mtl-2.2.2
    parser-combinators-1.3.0-5jHqYWwdpCqFWQLuYLRvi6 process-1.6.11.0
    text-1.2.4.1 transformers-0.5.6.2 unix-2.7.2.2
    unordered-containers-0.2.14.0-GZb439Gbt7L1ozynZzbOaU

haddock-interfaces:   /usr/share/doc/haskell-lsp0-test/html/lsp-test.haddock
haddock-html:         /usr/share/doc/haskell-lsp0-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
